@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.74';
+our $VERSION = '0.75';
 
 use Dist::Zilla 6.0;
 
@@ -171,6 +171,16 @@ has pod_coverage_trustme => (
     },
 );
 
+has pod_coverage_also_private => (
+    traits   => ['Array'],
+    is       => 'ro',
+    isa      => 'ArrayRef[Str]',
+    required => 1,
+    handles  => {
+        _has_coverage_also_private => 'count',
+    },
+);
+
 has stopwords => (
     traits   => ['Array'],
     is       => 'ro',
@@ -549,6 +559,11 @@ sub _pod_test_plugins {
     return (
         [
             'Test::Pod::Coverage::Configurable' => {
+                (
+                    $self->_has_coverage_also_private
+                    ? ( also_private => $self->pod_coverage_also_private )
+                    : ()
+                ),
                 (
                     $self->_has_coverage_skip
                     ? ( skip => $self->pod_coverage_skip )
@@ -765,7 +780,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.74
+version 0.75
 
 =head1 SYNOPSIS
 
@@ -785,8 +800,10 @@ version 0.74
     ; Passed to AutoPrereqs - can be repeated
     prereqs_skip = ...
     ; Passed to Test::Pod::Coverage::Configurable if set
+    pod_coverage_also_private = ...
+    ; Passed to Test::Pod::Coverage::Configurable if set - can be repeated
     pod_coverage_class = ...
-    ; Oassed to Test::Pod::Coverage::Configurable if set - can be repeated
+    ; Passed to Test::Pod::Coverage::Configurable if set - can be repeated
     pod_coverage_skip = ...
     ; Passed to Test::Pod::Coverage::Configurable if set - can be repeated
     pod_coverage_trustme = ...
@@ -1067,6 +1084,12 @@ button at L<http://www.urth.org/~autarch/fs-donation.html>.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Mark Fowler
+
+Mark Fowler <mark@twoshortplanks.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2016 by Dave Rolsky.
